Change Log
===========

0.0.11
------
- Downgrade to pandas 0.24.2 for Python 2.x support

0.0.10
------
- Init MANIFEST.in
- Include requirements.txt in MANIFEST.in

0.0.7
------
- Added support for `requests.request`

0.0.6
------
- Runtime events for Backtest

0.0.5
------
- PEP8 fixes for Backtest, using ZMQ

0.0.4
------
- Added Backtest related methods

0.0.3
------
- `helpers.bars_to_pandas()` parses numeric columns as numbers

0.0.2
------
- Added `helpers.bars_to_pandas()` method to convert bars payload to pandas dataframe

0.0.1
------
- Requests wrapper with helper methods
